@@ -1,61 +1,33 @@
 package CGI::Application::Plugin::Feedback;
 use strict; 
-use warnings;
 require Exporter;
-use vars(qw/@ISA @EXPORT_OK %EXPORT_TAGS/); 
+require CGI::Application;
+require CGI::Application::Plugin::Session;
+
+use vars qw/@ISA @EXPORT_OK %EXPORT_TAGS $VERSION/; 
+$VERSION = sprintf "%d.%02d", q$Revision: 1.5 $ =~ /(\d+)/g;
+
+# export ...
 @ISA = qw(Exporter);
-@EXPORT_OK = qw(feedback get_feedback_prepped feedback_exists get_feedback_html);
+@EXPORT_OK = qw(feedback get_feedback_prepped feedback_exists get_feedback_html get_feedback_text);
 %EXPORT_TAGS = (
  all =>  \@EXPORT_OK ,
 );
-our $VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ /(\d+)/g;
 
-=head1 NAME
-
-CGI::Application::Plugin::Feedback - simple end user feedback method
-
-=head1 SYNOPSIS
-
-	use CGI::Application::Plugin::Feedback ':all';		
-		
-	$self->feedback('hello.'); # now stored in session
-
-	$self->feedback('Yawn.'); # appended as new entry
-
-later, whenever you want.. 4 minutes later.. in another runmode..
-
-	$tmpl->param( FEEDBACK => get_feedback_prepped );
-
-later still..
-
-	$tmpl->param( FEEDBACK => get_feedback_prepped ); # nothing.
+sub import {   
+   __PACKAGE__->export_to_level(1,@_,@EXPORT_OK);
+}
 
 
-=head1 DESCRIPTION
-	
-Imagine a user calls runmode rm_make_pie, which itself just makes a pie.
-You want to tell the end user if it worked, if it did not, and why. And you
-want to do this just about as simply as you would tell yourself when you are debugging.
-
-This simple trinket has saved me a lot of coding time, and maintained my apps looking good,
-and providing useful information to an end user.
-
-Another example. Maybe you don't know exactly what your program will do, maybe feedback may be set
-from a variety of places, you can have feedback be set by whatever, and it only shows to the user
-when you call the template object output.
 
 
-=head1 METHODS
-
-None of these are exported by default. You can import them individually or import :all.
-
-=cut
 
 sub feedback {
 	my $self = shift;
 	my $add = shift; 
 
-	my $feedback = $self->session->param('feedback');
+   
+	my $feedback = $self->session->param('feedback');   
 
 	if ($add){
 		push @{$feedback}, $add;
@@ -71,50 +43,23 @@ sub feedback {
 	return $feedback;	
 }
 
-=head2 feedback()
-
-Argument is feedback to show. If no argument is provided, feedback array ref is returned
-and feedback is cleared from session.
-
-	$self->feedback('that worked, congrats!');
-
-If no argument, and no feedback exists, returns empty array ref [].
-Each feedback entry, argument, is a string.
-
-=cut
 
 sub feedback_exists {
 	my $self = shift;		
-	if ( defined $self->session->param('feedback') and scalar @{$self->session->param('feedback')} ){
+	if ( defined $self->session->param('feedback') 
+      and scalar @{$self->session->param('feedback')} 
+   ){
 		return 1;
 	}
 	return 0;
 }
 
-=head2 feedback_exists()
-
-takes no argument. returns boolean, true or false.
-unlike calling feedback() alone, it does not empty out the contents.
-
-=cut
-
-
-
-=head1 RETRIEVAL METHODS
-
-Note: Calling any of these methods will automatically clear the feedback in session.
-
-=cut
-
-
 sub get_feedback_html {
 	my $self = shift;
-
-	my $feedback = $self->feedback;
-	scalar @$feedback or return '';
+   $self->feedback_exists or return '';
 
 	my $html;
-	for( @$feedback ){
+	for( @{$self->feedback} ){
 		$html.= "<p>$_</p>";
 	}
 	return $html;
@@ -122,11 +67,9 @@ sub get_feedback_html {
 
 sub get_feedback_text {
 	my $self = shift;
+   $self->feedback_exists or return '';
 
-	my $feedback = $self->feedback;
-	scalar @$feedback or return '';
-
-	my $text = join("\n\n", @$feedback );
+	my $text = join("\n\n", @{$self->feedback} );
 	return $text;
 }
 
@@ -139,6 +82,81 @@ sub get_feedback_prepped {
 	return \@prepped;
 }
 
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+CGI::Application::Plugin::Feedback - simple end user feedback method
+
+=head1 SYNOPSIS
+
+	use CGI::Application::Plugin::Feedback;		
+		
+	$self->feedback('hello.'); # now stored in session
+
+	$self->feedback('Yawn.'); # appended as new entry
+
+# later, whenever you want.. 4 minutes later.. in another runmode..
+
+	$tmpl->param( FEEDBACK_LOOP => get_feedback_prepped ); # appropriate for HTML::Template loop
+   # or as text
+   my $feedback = $self->get_feedback_txt;
+
+   $tmpl->param( FEEDBACK_VAR => $feedback );
+   
+
+# later still..
+
+	$tmpl->param( FEEDBACK_LOOP => get_feedback_prepped ); # nothing.
+
+
+=head1 DESCRIPTION
+	
+Imagine a user calls runmode rm_make_pie, which itself just makes a pie.
+You want to tell the end user if it worked, if it did not, and why. And you
+want to do this just about as simply as you would tell yourself when you are debugging.
+
+This simple trinket has saved me a lot of coding time, and maintained my apps looking good,
+and providing useful information to an end user.
+
+Another example. Maybe you don't know exactly what your program will do, maybe feedback may be set
+from a variety of places, you can have feedback be set by whatever, and it only shows to the user
+when you call the template object output.
+
+This plugin has helped me cut down on my runmodes tremendously.
+
+=head1 METHODS
+
+Methods are exported to level 1, your cgi app.
+
+=head2 feedback()
+
+Argument is feedback to show. If no argument is provided, feedback array ref is returned
+and feedback is cleared from session.
+
+	$self->feedback('that worked, congrats!');
+
+If no argument, and no feedback exists, returns empty array ref [].
+Each feedback entry, argument, is a string.
+
+=head2 feedback_exists()
+
+takes no argument. returns boolean, true or false.
+unlike calling feedback() alone, it does not empty out the contents.
+
+
+=head1 RETRIEVAL METHODS
+
+Note: Calling any of these methods will automatically clear the feedback in session.
+
+=head2 feedback()
+
+returns array ref, will clear the feedback queue just like the following methods
+
 =head2 get_feedback_html()
 
 If you don't want to use a template, this subroutine will return your feedback as already formatted html.
@@ -247,6 +265,3 @@ Leo Charre leocharre at cpan dot org
 
 =cut
 
-
-
-1;
